@@ -20,6 +20,7 @@ import six
 
 from ceilometermiddleware import swift
 from ceilometermiddleware.tests import base as tests_base
+from threading import Event
 
 
 class FakeApp(object):
@@ -90,6 +91,31 @@ class TestSwift(tests_base.TestCase):
             self.assertEqual('obj', metadata['object'])
             self.assertEqual('get', data[2]['target']['action'])
 
+    def test_get_background(self):
+        notified = Event()
+        app = swift.Swift(FakeApp(),
+                          {"nonblocking_notify": "True",
+                           "send_queue_size": "1"})
+        req = FakeRequest('/1.0/account/container/obj',
+                          environ={'REQUEST_METHOD': 'GET'})
+        with mock.patch('oslo_messaging.Notifier.info',
+                        side_effect=lambda *args, **kwargs: notified.set()
+                        ) as notify:
+            resp = app(req.environ, self.start_response)
+            self.assertEqual(["This string is 28 bytes long"], list(resp))
+            notified.wait()
+            self.assertEqual(1, len(notify.call_args_list))
+            data = notify.call_args_list[0][0]
+            self.assertEqual('objectstore.http.request', data[1])
+            self.assertEqual(28, data[2]['measurements'][0]['result'])
+            self.assertEqual('storage.objects.outgoing.bytes',
+                             data[2]['measurements'][0]['metric']['name'])
+            metadata = data[2]['target']['metadata']
+            self.assertEqual('1.0', metadata['version'])
+            self.assertEqual('container', metadata['container'])
+            self.assertEqual('obj', metadata['object'])
+            self.assertEqual('get', data[2]['target']['action'])
+
     def test_put(self):
         app = swift.Swift(FakeApp(body=['']), {})
         req = FakeRequest(
@@ -317,7 +343,7 @@ class TestSwift(tests_base.TestCase):
             data = notify.call_args_list[0][0]
             self.assertEqual("account", data[2]['target']['id'])
 
-    def test_invalid_reseller_prefix(self):
+    def test_incomplete_reseller_prefix(self):
         # Custom reseller prefix set, but without trailing underscore
         app = swift.Swift(
             FakeApp(), {'reseller_prefix': 'CUSTOM'})
@@ -329,6 +355,17 @@ class TestSwift(tests_base.TestCase):
             data = notify.call_args_list[0][0]
             self.assertEqual("account", data[2]['target']['id'])
 
+    def test_invalid_reseller_prefix(self):
+        app = swift.Swift(
+            FakeApp(), {'reseller_prefix': 'AUTH_'})
+        req = FakeRequest('/1.0/admin/bucket',
+                          environ={'REQUEST_METHOD': 'GET'})
+        with mock.patch('oslo_messaging.Notifier.info') as notify:
+            list(app(req.environ, self.start_response))
+            self.assertEqual(1, len(notify.call_args_list))
+            data = notify.call_args_list[0][0]
+            self.assertEqual("1.0/admin/bucket", data[2]['target']['id'])
+
     def test_ignore_requests_from_project(self):
         app = swift.Swift(FakeApp(), {'ignore_projects': 'skip_proj'})
 
